/* 

This is the usr_function file for the j1-j2-j3 honeycomb HAFM,
but with J2 not equal to J3 in this case.

Model state III. An AF spiral in the x-diraction.

See Fouet et al., Euro. Phys. J. B. 20, 241-254 (2001) for
a description of the classical ground state. In particular,
see figure 2 for the case of J1>0 & J2>0 & J3>0.  

Designed by Damian JJ Farnell. 5 May 2011.
 
*/

#define _USR_PARAMETER_ "j1j2j3 honeycomb model state III"
// added by Joerg 2011-07-11
#define UseAlpha 1       // one parameter
#define SearchAlphaMin 2 // 0=startAlpha_only or 1=fix_steps, 2=dynamic_search
#define StartAlpha    (0.5714528*M_PI)
#define StepAlpha     (0.001*M_PI)   // 0.01*M_PI

double usr_parameter(int bonds, double alpha)
{
  // condition for triangular AF in external field: both model states

   double j1=1.0,j2=0.0,j3=0.0;

   j1=1.0;   // put the value of j2 in here. 
   j2=alpha; // put the value of j2 in here.  
   //  j3=alpha;   // put the value of j3 in here.    //  original
   j3=0.0;   // put the value of j3 in here.    //  PL 

    if (bonds==1 || bonds==2) 
      return j1; // obviously, the J1 bonds 
    if (bonds==3 || bonds==4) 
      return j2;  // obviously, the J2 bonds 
    if (bonds==5 || bonds==6) 
      return j3;  // obviously, the J3 bonds 
	
}

double usr_angle(int bonds, int term13, double *alpha, int numalpha)
{

  double mult = 0.0;  
  
  double phi=alpha[0];
  
    if (bonds==1) 
        phi=0.0;         // phi not used in this case. Pure AF case.
    if (bonds==2) 
        phi=M_PI+phi;    
    if (bonds==3) 
        phi=phi;    
    if (bonds==4) 
        phi=2*phi;    
    if (bonds==5) 
        phi=0.0;        // phi not used in this case. Pure AF case.
    if (bonds==6) 
        phi=M_PI+2*phi;  
  
  if (bonds==1 || bonds==5) {  
	// note factor of 0.5 here to make counting right.
    if      (term13 == 1) mult= -0.5;                    // s^z s^z 
    else if (term13 == 8) mult= -0.25;                   // s^+ s^+
    else if (term13 == 9) mult= -0.25;                   // s^- s^-
  } else  {
    if      (term13 == 1) mult=       cos(phi);           // s^z s^z 
    else if (term13 == 2) mult=  -0.5*sin(phi);           // s^z s^+ 
    else if (term13 == 3) mult=  -0.5*sin(phi);           // s^z s^-
    else if (term13 == 4) mult=   0.5*sin(phi);           // s^+ s^z
    else if (term13 == 5) mult=   0.5*sin(phi);           // s^- s^z
    else if (term13 == 6) mult=  0.25*(1.0+cos(phi));     // s^+ s^-
    else if (term13 == 7) mult=  0.25*(1.0+cos(phi));     // s^- s^+
    else if (term13 == 8) mult=  0.25*(cos(phi)-1.0);     // s^+ s^+
    else if (term13 == 9) mult=  0.25*(cos(phi)-1.0);     // s^- s^-
  }
  return mult;
}


